/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.filing.earlyEngineering.mapper;

import com.jeeplus.core.persistence.BaseMapper;
import com.jeeplus.core.persistence.annotation.MyBatisMapper;
import com.jeeplus.modules.filing.earlyEngineering.entity.EarlyEngineering;

import java.util.List;

/**
 * 依法合规MAPPER接口
 * @author qy
 * @version 2021-04-06
 */
@MyBatisMapper
public interface EarlyEngineeringMapper extends BaseMapper<EarlyEngineering> {
    List<EarlyEngineering> findChildList(EarlyEngineering entity);

    Integer findByCode(EarlyEngineering entity);


    /**
     * 通过id集合查询出所有符合条件的项目基础信息
     */
    List<EarlyEngineering> findByIdList(List<String> idList);

    /**
     * 通过项目id查询出所有的项目信息
     * */
    List<EarlyEngineering> findAll(List<String> idList);

    Integer findDesignStage(EarlyEngineering entity);

    Integer findReviewStage(EarlyEngineering entity);

    Integer findBiddingContract(EarlyEngineering entity);

    Integer findApplicationFor(EarlyEngineering entity);

    Integer findLegalCompliance(EarlyEngineering entity);

    void insertDesign(EarlyEngineering entity);
    void updateDesign(EarlyEngineering entity);
    void insertReviewStage(EarlyEngineering entity);
    void updateReviewStage(EarlyEngineering entity);
    void insertBiddingContract(EarlyEngineering entity);
    void updateBiddingContract(EarlyEngineering entity);
    void insertApplicationFor(EarlyEngineering entity);
    void updateApplicationFor(EarlyEngineering entity);
    void insertLegalCompliance(EarlyEngineering entity);
    void updateLegalCompliance(EarlyEngineering entity);
}